@@ -68,7 +68,9 @@ class ConnectionManager:
             if self.controller.login_done == False:
                 self.logger.network("Network connection established, starting authentication")
                 self.controller.start_trusted_auth()
-                self.ui_handler.try_trusted_login()
+                trusted_login_ui = self.ui_handler.trusted_login_ui
+                if trusted_login_ui.line_edit_email.text().isEmpty() == False and trusted_login_ui.line_edit_password.text().isEmpty() == False:
+                    self.ui_handler.try_trusted_login()
             elif self.controller.connected == True and self.client != None:
                 if len(self.queued_threads) > 0:
                     self.ui_handler.show_information_ui("Connection established, fetching queued tasks", True)
